@@ -15,5 +15,5 @@ test_that("can standardise generics", {
 test_that("base ops use S7 shim", {
   expect_equal(as_generic(`+`), base_ops[["+"]])
   if(getRversion() >= "4.3.0")
-    expect_equal(as_generic(`%*%`), base_ops[["%*%"]])
+    expect_equal(as_generic(`%*%`), base_matrix_ops[["%*%"]])
 })
